@@ -113,15 +113,3 @@ def get_server_config() -> Dict[str, Any]:
 
 def set_server_config(server_config: Dict[str, Any]) -> None:
     get_deploy_config().set_server_config(server_config)
-
-
-def get_workflow_config(dataset: str, access_level: str, driver_image:str, output_prefix: str) -> Dict[str, Any]:
-    deploy_config = get_deploy_config()
-    return {
-        'access_level': access_level,
-        'dataset': dataset,
-        'driver_image': driver_image,
-        'image_registry_prefix': f'{deploy_config.container_registry}/cpg-common/images',
-        'reference_prefix': deploy_config.reference_base,
-        'output_prefix': output_prefix
-    }
